unit Unit1;

interface

uses
  Classes, SysUtils, IWAppForm, IWApplication, IWColor, IWTypes, VclTee.TeeGDIPlus, VCLTee.TeEngine, Vcl.Controls, Vcl.ExtCtrls,
  VCLTee.TeeProcs, VCLTee.Chart, IWVCLBaseControl, IWBaseControl, IWBaseHTMLControl, IWControl, IWCompExtCtrls;

type
  TIWForm1 = class(TIWAppForm)
    Chart1: TChart;
    TurnoverImage: TIWImage;
    procedure IWAppFormCreate(Sender: TObject);
  public
    procedure ShowTurnoverChart;
    procedure CopyChartToImage(const aChart: TChart; const aImage: TIWImage);
  end;

implementation

uses
  Winapi.GDIPOBJ, Winapi.GDIPAPI, VCLTee.Series, Winapi.Windows, Vcl.Graphics;

{$R *.dfm}


{ TIWForm1 }

procedure TIWForm1.CopyChartToImage(const aChart: TChart; const aImage: TIWImage);
var
	xMetaFile: TMetafile;
	xBitmap: TBitmap;
	xRect: TRect;
begin
	xBitmap := aImage.Picture.Bitmap;
	xBitmap.Width := aChart.Width;
	xBitmap.Height := aChart.Height;
//	aImage.Width := aChart.Width;
//	aImage.Height := aChart.Height;

	xRect := Rect(0, 0, aChart.Width, aChart.Height);
	aChart.BufferedDisplay := False;
	xMetaFile := aChart.TeeCreateMetafile(False, xRect);
	try
		xBitmap.Canvas.Draw(0, 0, xMetaFile);
	finally
		FreeAndNil(xMetaFile);
	end;
end;

procedure TIWForm1.IWAppFormCreate(Sender: TObject);
begin
  ShowTurnoverChart;
end;

procedure TIWForm1.ShowTurnoverChart;
var
  I: Integer;
	TurnoverChart: TChart;
	LSYbInv, LSYbEnt, LSYInv, LSYEnt: TLineSeries;
begin
	TurnoverChart := TChart.Create(nil);
	TurnoverChart.Width := TurnoverImage.Width;
	TurnoverChart.Height := TurnoverImage.Height;
	TurnoverChart.Title.Font.Size := 10;
	TurnoverChart.Title.Font.Style := [fsBold];
	TurnoverChart.Title.Caption := 'Turnover / Orders';
	TurnoverChart.BackWall.Dark3D := false;
	TurnoverChart.BevelOuter := bvNone;
	TurnoverChart.Border.Visible := true;
	TurnoverChart.Border.Color := clGray;
	TurnoverChart.BorderRound := 5;
	TurnoverChart.BorderWidth := 1;
	TurnoverChart.View3D := false;

	try
		LSYInv := TLineSeries.Create(TurnoverChart);
		TurnoverChart.AddSeries(LSYInv);
		LSYInv.Title := Format('Turnover %d', [2015]);
		LSYInv.LinePen.Width := 2;

		LSYEnt := TLineSeries.Create(TurnoverChart);
		TurnoverChart.AddSeries(LSYEnt);
		LSYEnt.Title := Format('Orders %d', [2015]);
		LSYEnt.LinePen.Width := 2;

		LSYbInv := TLineSeries.Create(TurnoverChart);
		TurnoverChart.AddSeries(LSYbInv);
		LSYbInv.Title := Format('Turnover %d', [2014]);

		LSYbEnt := TLineSeries.Create(TurnoverChart);
		TurnoverChart.AddSeries(LSYbEnt);
		LSYbEnt.Title := Format('Orders %d', [2014]);

		try
      Randomize;
      for I := 0 to 11 do
      begin
        LSYbInv.Add(Random(1000), I.ToString, clTeeColor);
        LSYbEnt.Add(Random(1000), I.ToString, clTeeColor);
        LSYInv.Add(Random(1000), I.ToString, clTeeColor);
        LSYEnt.Add(Random(1000), I.ToString, clTeeColor);
			end;

			CopyChartToImage(TurnoverChart, TurnoverImage);
		finally
			LSYbInv.Free;
			LSYbEnt.Free;
			LSYInv.Free;
			LSYEnt.Free;
		end;
	finally
		TurnoverChart.Free;
	end;
end;

procedure GDIPlus_Initialize;
begin
	StartupInput.DebugEventCallback := nil;
	StartupInput.SuppressBackgroundThread := False;
	StartupInput.SuppressExternalCodecs := False;
	StartupInput.GdiplusVersion := 1;

	GdiplusStartup(gdiplusToken, @StartupInput, nil);
end;

procedure GDIPlus_Finalize;
begin
	if Assigned(GenericSansSerifFontFamily) then
		GenericSansSerifFontFamily.Free;
	if Assigned(GenericSerifFontFamily) then
		GenericSerifFontFamily.Free;
	if Assigned(GenericMonospaceFontFamily) then
		GenericMonospaceFontFamily.Free;
	if Assigned(GenericTypographicStringFormatBuffer) then
		GenericTypographicStringFormatBuffer.free;
	if Assigned(GenericDefaultStringFormatBuffer) then
		GenericDefaultStringFormatBuffer.Free;

	GdiplusShutdown(gdiplusToken);
end;


initialization
  TIWForm1.SetAsMainForm;
  GDIPlus_Initialize;

finalization
  GDIPlus_Finalize;

end.
